/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface D1DatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
    * Account identifier tag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database#account_id D1Database#account_id}
    */
    readonly accountId: string;
    /**
    * D1 database name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database#name D1Database#name}
    */
    readonly name: string;
    /**
    * Specify the region to create the D1 primary, if available. If this option is omitted, the D1 will be created as close as possible to the current user.
    * Available values: "wnam", "enam", "weur", "eeur", "apac", "oc".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database#primary_location_hint D1Database#primary_location_hint}
    */
    readonly primaryLocationHint?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database cloudflare_d1_database}
*/
export declare class D1Database extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_d1_database";
    /**
    * Generates CDKTF code for importing a D1Database resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the D1Database to import
    * @param importFromId The id of the existing D1Database that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the D1Database to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/d1_database cloudflare_d1_database} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options D1DatabaseConfig
    */
    constructor(scope: Construct, id: string, config: D1DatabaseConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdAt(): string;
    get fileSize(): number;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numTables(): number;
    private _primaryLocationHint?;
    get primaryLocationHint(): string;
    set primaryLocationHint(value: string);
    resetPrimaryLocationHint(): void;
    get primaryLocationHintInput(): string | undefined;
    get uuid(): string;
    get version(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
