/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareCloudConnectorRulesListConfig extends cdktf.TerraformMetaArguments {
    /**
    * Max items to fetch, default: 1000
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/cloud_connector_rules_list#max_items DataCloudflareCloudConnectorRulesList#max_items}
    */
    readonly maxItems?: number;
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/cloud_connector_rules_list#zone_id DataCloudflareCloudConnectorRulesList#zone_id}
    */
    readonly zoneId: string;
}
export interface DataCloudflareCloudConnectorRulesListResultParameters {
}
export declare function dataCloudflareCloudConnectorRulesListResultParametersToTerraform(struct?: DataCloudflareCloudConnectorRulesListResultParameters): any;
export declare function dataCloudflareCloudConnectorRulesListResultParametersToHclTerraform(struct?: DataCloudflareCloudConnectorRulesListResultParameters): any;
export declare class DataCloudflareCloudConnectorRulesListResultParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareCloudConnectorRulesListResultParameters | undefined;
    set internalValue(value: DataCloudflareCloudConnectorRulesListResultParameters | undefined);
    get host(): string;
}
export interface DataCloudflareCloudConnectorRulesListResult {
}
export declare function dataCloudflareCloudConnectorRulesListResultToTerraform(struct?: DataCloudflareCloudConnectorRulesListResult): any;
export declare function dataCloudflareCloudConnectorRulesListResultToHclTerraform(struct?: DataCloudflareCloudConnectorRulesListResult): any;
export declare class DataCloudflareCloudConnectorRulesListResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataCloudflareCloudConnectorRulesListResult | undefined;
    set internalValue(value: DataCloudflareCloudConnectorRulesListResult | undefined);
    get cloudProvider(): string;
    get description(): string;
    get enabled(): cdktf.IResolvable;
    get expression(): string;
    get id(): string;
    private _parameters;
    get parameters(): DataCloudflareCloudConnectorRulesListResultParametersOutputReference;
}
export declare class DataCloudflareCloudConnectorRulesListResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataCloudflareCloudConnectorRulesListResultOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/cloud_connector_rules_list cloudflare_cloud_connector_rules_list}
*/
export declare class DataCloudflareCloudConnectorRulesList extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_cloud_connector_rules_list";
    /**
    * Generates CDKTF code for importing a DataCloudflareCloudConnectorRulesList resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareCloudConnectorRulesList to import
    * @param importFromId The id of the existing DataCloudflareCloudConnectorRulesList that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/cloud_connector_rules_list#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareCloudConnectorRulesList to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/cloud_connector_rules_list cloudflare_cloud_connector_rules_list} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareCloudConnectorRulesListConfig
    */
    constructor(scope: Construct, id: string, config: DataCloudflareCloudConnectorRulesListConfig);
    private _maxItems?;
    get maxItems(): number;
    set maxItems(value: number);
    resetMaxItems(): void;
    get maxItemsInput(): number | undefined;
    private _result;
    get result(): DataCloudflareCloudConnectorRulesListResultList;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
