/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareWorkersForPlatformsScriptSecretsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets#account_id DataCloudflareWorkersForPlatformsScriptSecrets#account_id}
    */
    readonly accountId: string;
    /**
    * Name of the Workers for Platforms dispatch namespace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets#dispatch_namespace DataCloudflareWorkersForPlatformsScriptSecrets#dispatch_namespace}
    */
    readonly dispatchNamespace: string;
    /**
    * Max items to fetch, default: 1000
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets#max_items DataCloudflareWorkersForPlatformsScriptSecrets#max_items}
    */
    readonly maxItems?: number;
    /**
    * Name of the script, used in URLs and route configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets#script_name DataCloudflareWorkersForPlatformsScriptSecrets#script_name}
    */
    readonly scriptName: string;
}
export interface DataCloudflareWorkersForPlatformsScriptSecretsResult {
}
export declare function dataCloudflareWorkersForPlatformsScriptSecretsResultToTerraform(struct?: DataCloudflareWorkersForPlatformsScriptSecretsResult): any;
export declare function dataCloudflareWorkersForPlatformsScriptSecretsResultToHclTerraform(struct?: DataCloudflareWorkersForPlatformsScriptSecretsResult): any;
export declare class DataCloudflareWorkersForPlatformsScriptSecretsResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataCloudflareWorkersForPlatformsScriptSecretsResult | undefined;
    set internalValue(value: DataCloudflareWorkersForPlatformsScriptSecretsResult | undefined);
    get name(): string;
    get type(): string;
}
export declare class DataCloudflareWorkersForPlatformsScriptSecretsResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataCloudflareWorkersForPlatformsScriptSecretsResultOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets cloudflare_workers_for_platforms_script_secrets}
*/
export declare class DataCloudflareWorkersForPlatformsScriptSecrets extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_workers_for_platforms_script_secrets";
    /**
    * Generates CDKTF code for importing a DataCloudflareWorkersForPlatformsScriptSecrets resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareWorkersForPlatformsScriptSecrets to import
    * @param importFromId The id of the existing DataCloudflareWorkersForPlatformsScriptSecrets that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareWorkersForPlatformsScriptSecrets to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/data-sources/workers_for_platforms_script_secrets cloudflare_workers_for_platforms_script_secrets} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareWorkersForPlatformsScriptSecretsConfig
    */
    constructor(scope: Construct, id: string, config: DataCloudflareWorkersForPlatformsScriptSecretsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _dispatchNamespace?;
    get dispatchNamespace(): string;
    set dispatchNamespace(value: string);
    get dispatchNamespaceInput(): string | undefined;
    private _maxItems?;
    get maxItems(): number;
    set maxItems(value: number);
    resetMaxItems(): void;
    get maxItemsInput(): number | undefined;
    private _result;
    get result(): DataCloudflareWorkersForPlatformsScriptSecretsResultList;
    private _scriptName?;
    get scriptName(): string;
    set scriptName(value: string);
    get scriptNameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
