/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WorkersRouteConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route#pattern WorkersRoute#pattern}
    */
    readonly pattern: string;
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route#route_id WorkersRoute#route_id}
    */
    readonly routeId?: string;
    /**
    * Name of the script, used in URLs and route configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route#script WorkersRoute#script}
    */
    readonly script?: string;
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route#zone_id WorkersRoute#zone_id}
    */
    readonly zoneId: string;
}
export interface WorkersRouteErrorsSource {
}
export declare function workersRouteErrorsSourceToTerraform(struct?: WorkersRouteErrorsSource): any;
export declare function workersRouteErrorsSourceToHclTerraform(struct?: WorkersRouteErrorsSource): any;
export declare class WorkersRouteErrorsSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersRouteErrorsSource | undefined;
    set internalValue(value: WorkersRouteErrorsSource | undefined);
    get pointer(): string;
}
export interface WorkersRouteErrors {
}
export declare function workersRouteErrorsToTerraform(struct?: WorkersRouteErrors): any;
export declare function workersRouteErrorsToHclTerraform(struct?: WorkersRouteErrors): any;
export declare class WorkersRouteErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersRouteErrors | undefined;
    set internalValue(value: WorkersRouteErrors | undefined);
    get code(): number;
    get documentationUrl(): string;
    get message(): string;
    private _source;
    get source(): WorkersRouteErrorsSourceOutputReference;
}
export declare class WorkersRouteErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersRouteErrorsOutputReference;
}
export interface WorkersRouteMessagesSource {
}
export declare function workersRouteMessagesSourceToTerraform(struct?: WorkersRouteMessagesSource): any;
export declare function workersRouteMessagesSourceToHclTerraform(struct?: WorkersRouteMessagesSource): any;
export declare class WorkersRouteMessagesSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersRouteMessagesSource | undefined;
    set internalValue(value: WorkersRouteMessagesSource | undefined);
    get pointer(): string;
}
export interface WorkersRouteMessages {
}
export declare function workersRouteMessagesToTerraform(struct?: WorkersRouteMessages): any;
export declare function workersRouteMessagesToHclTerraform(struct?: WorkersRouteMessages): any;
export declare class WorkersRouteMessagesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersRouteMessages | undefined;
    set internalValue(value: WorkersRouteMessages | undefined);
    get code(): number;
    get documentationUrl(): string;
    get message(): string;
    private _source;
    get source(): WorkersRouteMessagesSourceOutputReference;
}
export declare class WorkersRouteMessagesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersRouteMessagesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route cloudflare_workers_route}
*/
export declare class WorkersRoute extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_workers_route";
    /**
    * Generates CDKTF code for importing a WorkersRoute resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WorkersRoute to import
    * @param importFromId The id of the existing WorkersRoute that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WorkersRoute to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/workers_route cloudflare_workers_route} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WorkersRouteConfig
    */
    constructor(scope: Construct, id: string, config: WorkersRouteConfig);
    private _errors;
    get errors(): WorkersRouteErrorsList;
    get id(): string;
    private _messages;
    get messages(): WorkersRouteMessagesList;
    private _pattern?;
    get pattern(): string;
    set pattern(value: string);
    get patternInput(): string | undefined;
    private _routeId?;
    get routeId(): string;
    set routeId(value: string);
    resetRouteId(): void;
    get routeIdInput(): string | undefined;
    private _script?;
    get script(): string;
    set script(value: string);
    resetScript(): void;
    get scriptInput(): string | undefined;
    get success(): cdktf.IResolvable;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
