/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZoneSettingConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the zone setting.
    * Available values: "0rtt".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting#id ZoneSetting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Setting name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting#setting_id ZoneSetting#setting_id}
    */
    readonly settingId: string;
    /**
    * Current value of the zone setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting#value ZoneSetting#value}
    */
    readonly value: {
        [key: string]: any;
    };
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting#zone_id ZoneSetting#zone_id}
    */
    readonly zoneId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting cloudflare_zone_setting}
*/
export declare class ZoneSetting extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zone_setting";
    /**
    * Generates CDKTF code for importing a ZoneSetting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZoneSetting to import
    * @param importFromId The id of the existing ZoneSetting that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZoneSetting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.3.0/docs/resources/zone_setting cloudflare_zone_setting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZoneSettingConfig
    */
    constructor(scope: Construct, id: string, config: ZoneSettingConfig);
    get editable(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get modifiedOn(): string;
    private _settingId?;
    get settingId(): string;
    set settingId(value: string);
    get settingIdInput(): string | undefined;
    get timeRemaining(): number;
    private _value?;
    get value(): {
        [key: string]: any;
    };
    set value(value: {
        [key: string]: any;
    });
    get valueInput(): {
        [key: string]: any;
    } | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
